CSET Operators
==============

This page details the operators contained within CSET. It is automatically
generated from the code and its docstrings. Operators should be used via
:doc:`/usage/operator-recipes`.

Generic Operators
~~~~~~~~~~~~~~~~~

CSET.operators.aggregate
------------------------

.. automodule:: CSET.operators.aggregate
   :members:

CSET.operators.transect
---------------------------

.. automodule:: CSET.operators.transect
   :members:

CSET.operators.collapse
-----------------------

.. automodule:: CSET.operators.collapse
   :members:

CSET.operators.constraints
--------------------------

.. automodule:: CSET.operators.constraints
   :members:

CSET.operators.filters
----------------------

.. automodule:: CSET.operators.filters
   :members:

CSET.operators.misc
-------------------

.. automodule:: CSET.operators.misc
   :members:

CSET.operators.plot
--------------------------

.. automodule:: CSET.operators.plot
   :members:

CSET.operators.read
-------------------

.. automodule:: CSET.operators.read
   :members:

CSET.operators.regrid
---------------------

.. automodule:: CSET.operators.regrid
   :members:

CSET.operators.write
--------------------

.. automodule:: CSET.operators.write
   :members:

Convection Operators
~~~~~~~~~~~~~~~~~~~~

CSET.operators.convection
-------------------------

.. automodule:: CSET.operators.convection
   :members:

Ensemble Operators
~~~~~~~~~~~~~~~~~~

CSET.operators.ensembles
------------------------

.. automodule:: CSET.operators.ensembles
   :members:

Mesoscale Operators
~~~~~~~~~~~~~~~~~~~

CSET.operators.mesoscale
------------------------

.. automodule:: CSET.operators.mesoscale
   :members:

Other
~~~~~

CSET.operators.ageofair
-----------------------

.. automodule:: CSET.operators.ageofair
   :members:
